AnimatedSize class

Animated widget that automatically transitions its size over a given duration whenever the given child's size changes.

{@tool dartpad} This example makes a Container react to being touched, causing the child of the AnimatedSize widget, here a FlutterLogo, to animate.

** See code in examples/api/lib/widgets/animated_size/animated_size.0.dart ** {@end-tool}

See also:

Inheritance

Constructors

AnimatedSize({Key? key, Widget? child, AlignmentGeometry alignment = Alignment.center, Curve curve = Curves.linear, required Duration duration, Duration? reverseDuration, Clip clipBehavior = Clip.hardEdge})
Creates a widget that animates its size to match that of its child.
const

Properties

alignment → AlignmentGeometry
The alignment of the child within the parent when the parent is not yet the same size as the child.
final
child → Widget?
The widget below this widget in the tree.
final
clipBehavior → Clip
The content will be clipped (or not) according to this option.
final
curve → Curve
The animation curve when transitioning this widget's size to match the child's size.
final
duration → Duration
The duration when transitioning this widget's size to match the child's size.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
reverseDuration → Duration?
The duration when transitioning this widget's size to match the child's size when going in reverse.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited